Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Zone string
SocketPath string
RecordRTTs bool
PingMinQph int
PrometheusMetricsFrequency time.Duration
}
Configuration variables for the Parser struct.
type Parser ¶
type Parser struct {
// contains filtered or unexported fields
}
Parser is the component in charge of reading and parsing dnstap from a UNIX socket and processing these messages to collect aggregate statistics.
func New ¶
func New(conf Config, resolverMap *stats.ResolverInfoMap, zoneStats *stats.ZoneStats, messages chan *dnstap.Message, pingQueue chan<- *stats.ResolverInfo) *Parser
Creates and returns a new Parser component. One Parser is created for each configured DNS zone.
func (*Parser) ComponentName ¶
Click to show internal directories.
Click to hide internal directories.